# Creating a New Release

Simple check list to go through for creating a new release

- [ ] Create new release on GitHub (with the new tag)
- [ ] Create and land a PR with updated version in `.pre-commit.config.yaml` e.g. using `pre-commit autoupdate`

Important to note is that the time between merging the PR with the new release
version and the creation of the new release should be minimal.
